﻿using System;

namespace ELTE.BoardGame.View
{
    /// <summary>
    /// Játéktábla nézetmodell típusa.
    /// </summary>
    public class BoardViewModel
    {
        #region Constructors

        /// <summary>
        /// Nézetmodell példányosítása
        /// </summary>
        /// <param name="newGameAction">Új játék akciója.</param>
        /// <param name="loadGameAction">Játék betöltés akciója.</param>
        /// <param name="saveGameAction">Játék mentés akciója.</param>
        public BoardViewModel(Action<Object> newGameAction, Action<Object> loadGameAction, Action<Object> saveGameAction)
        {
            // parancsok kezelése
            NewGameCommand = new DelegateCommand(newGameAction);
            LoadGameCommand = new DelegateCommand(loadGameAction);
            SaveGameCommand = new DelegateCommand(saveGameAction);
        }

        #endregion

        #region

        /// <summary>
        /// Új játék kezdése parancs lekérdezése.
        /// </summary>
        public DelegateCommand NewGameCommand { get; private set; }

        /// <summary>
        /// Játék betöltése parancs lekérdezése.
        /// </summary>
        public DelegateCommand LoadGameCommand { get; private set; }

        /// <summary>
        /// Játék mentése parancs lekérdezése.
        /// </summary>
        public DelegateCommand SaveGameCommand { get; private set; }

        /// <summary>
        /// Kilépés parancs lekérdezése.
        /// </summary>
        public DelegateCommand ExitGameCommand { get; private set; }

        /// <summary>
        /// Tábla szélességének lekérdezése, vagy beállítása.
        /// </summary>
        public Int32 BoardWidth { get; set; }

        /// <summary>
        /// Tábla magasságának lekérdezése, vagy beállítása.
        /// </summary>
        public Int32 BoardHeight { get; set; }

        /// <summary>
        /// Tábla elemeinek lekérdezése, vagy beállítása.
        /// </summary>
        public BoardItemViewModel[] BoardItems { get; set; }

        #endregion        
    }
}
